@@ -247,3 +247,18 @@ class P100():
 		decryptedResponse = self.tpLinkCipher.decrypt(r.json()["result"]["response"])
 
 		return decryptedResponse
+
+	def getDeviceName(self):
+		self.handshake()
+		self.login()
+		data = self.getDeviceInfo()
+
+		data = json.loads(data)
+
+		if data["error_code"] != 0:
+			errorCode = ast.literal_eval(decryptedResponse)["error_code"]
+			errorMessage = self.errorCodes[str(errorCode)]
+		else:
+			encodedName = data["result"]["nickname"]
+			name = b64decode(encodedName)
+			return name.decode("utf-8")
